@@ -8,6 +8,11 @@ from annif.suggestion import ListSuggestionResult
 class ChunkingBackend(metaclass=abc.ABCMeta):
     """Annif backend mixin that implements chunking of input"""
 
+    DEFAULT_PARAMS = {'chunksize': 1}
+
+    def default_params(self):
+        return self.DEFAULT_PARAMS
+
     @abc.abstractmethod
     def _suggest_chunks(self, chunktexts, project):
         """Suggest subjects for the chunked text; should be implemented by
