@@ -2,12 +2,12 @@
 
 
 from .document import DocumentDirectory, DocumentFile, DocumentList
-from .subject import Subject, SubjectDirectory, SubjectFileTSV
+from .subject import Subject, SubjectFileTSV
 from .subject import SubjectIndex, SubjectSet
 from .skos import SubjectFileSKOS
 from .types import Document
 from .combine import CombinedCorpus
 
 __all__ = [DocumentDirectory, DocumentFile, DocumentList, Subject,
-           SubjectDirectory, SubjectFileTSV, SubjectIndex, SubjectSet,
-           SubjectFileSKOS, Document, CombinedCorpus]
+           SubjectFileTSV, SubjectIndex, SubjectSet, SubjectFileSKOS,
+           Document, CombinedCorpus]
