@@ -137,7 +137,8 @@ class EvaluationBatch:
         y_true = np.array([gold_subjects.as_vector(self._subject_index)
                            for hits, gold_subjects in self._samples])
         y_pred = np.array([hits.vector
-                           for hits, gold_subjects in self._samples])
+                           for hits, gold_subjects in self._samples],
+                          dtype=np.float32)
 
         results = self._evaluate_samples(
             y_true, y_pred, metrics)
