@@ -1,6 +1,7 @@
 """Unit tests for backends in Annif"""
 
 import pytest
+import logging
 import annif
 import annif.backend
 import annif.corpus
@@ -13,7 +14,7 @@ def test_get_backend_nonexistent():
 
 def test_get_backend_dummy(app, project):
     dummy_type = annif.backend.get_backend("dummy")
-    dummy = dummy_type(backend_id='dummy', params={},
+    dummy = dummy_type(backend_id='dummy', config_params={},
                        datadir=app.config['DATADIR'])
     result = dummy.suggest(text='this is some text', project=project)
     assert len(result) == 1
@@ -24,7 +25,7 @@ def test_get_backend_dummy(app, project):
 
 def test_learn_dummy(app, project, tmpdir):
     dummy_type = annif.backend.get_backend("dummy")
-    dummy = dummy_type(backend_id='dummy', params={},
+    dummy = dummy_type(backend_id='dummy', config_params={},
                        datadir=app.config['DATADIR'])
 
     tmpdir.join('doc1.txt').write('doc1')
@@ -40,3 +41,11 @@ def test_learn_dummy(app, project, tmpdir):
     assert result[0].uri == 'http://example.org/key1'
     assert result[0].label == 'key1'
     assert result[0].score == 1.0
+
+
+def test_fill_params_with_defaults(app):
+    dummy_type = annif.backend.get_backend('dummy')
+    dummy = dummy_type(backend_id='dummy', config_params={},
+                       datadir=app.config['DATADIR'])
+    expected_default_params = {'limit': 100}  # From AnnifBackend class
+    assert expected_default_params == dummy.params
